@@ -1,4 +1,4 @@
-/* $Id: udpkg.h 11748 2004-03-22 21:26:43Z joeyh $ */
+/* $Id: udpkg.h 32636 2005-12-01 15:43:45Z sferriol-guest $ */
 #ifndef _UDPKG_H_
 #define _UDPKG_H_
 
@@ -49,7 +49,7 @@
 #define STATUS_STATUSCONFIGFILES	(1 << 14)
 #define STATUS_STATUSPOSTINSTFAILED	(1 << 15)
 #define STATUS_STATUSREMOVALFAILED	(1 << 16)
-#define STATUS_STATUSMASK		~(STATUS_STATUSNOTINSTALLED | STATUS_STATUSUNPACKED | STATUS_STATUSHALFCONFIGURED | STATUS_STATUSCONFIGFILES | STATUS_STATUSPOSTINSTFAILED | STATUS_STATUSREMOVALFAILED | STATUS_STATUSHALFINSTALLED)
+#define STATUS_STATUSMASK		~(STATUS_STATUSNOTINSTALLED | STATUS_STATUSUNPACKED | STATUS_STATUSHALFCONFIGURED | STATUS_STATUSINSTALLED | STATUS_STATUSCONFIGFILES | STATUS_STATUSPOSTINSTFAILED | STATUS_STATUSREMOVALFAILED | STATUS_STATUSHALFINSTALLED)
 
 #define COLOR_WHITE			0
 #define COLOR_GRAY			1
